@@ -1,44 +1,78 @@
-import inspect
 import functools
+import inspect
 import sys
 import warnings
-from collections.abc import Iterable
 
 import numpy as np
-import scipy
-from numpy.lib import NumpyVersion
 
 from ._warnings import all_warnings, warn
 
-
-__all__ = ['deprecated', 'get_bound_method_class', 'all_warnings',
-           'safe_as_int', 'check_shape_equality', 'check_nD', 'warn',
-           'reshape_nd', 'identity', 'slice_at_axis']
+__all__ = [
+    'deprecate_func',
+    'get_bound_method_class',
+    'all_warnings',
+    'safe_as_int',
+    'check_shape_equality',
+    'check_nD',
+    'warn',
+    'reshape_nd',
+    'identity',
+    'slice_at_axis',
+    "deprecate_parameter",
+    "DEPRECATED",
+]
 
 
-class skimage_deprecation(Warning):
-    """Create our own deprecation class, since Python >= 2.7
-    silences deprecations by default.
+def _count_wrappers(func):
+    """Count the number of wrappers around `func`."""
+    unwrapped = func
+    count = 0
+    while hasattr(unwrapped, "__wrapped__"):
+        unwrapped = unwrapped.__wrapped__
+        count += 1
+    return count
 
+
+def _warning_stacklevel(func):
+    """Find stacklevel for a warning raised from a wrapper around `func`.
+
+    Try to determine the number of
+
+    Parameters
+    ----------
+    func : Callable
+
+
+    Returns
+    -------
+    stacklevel : int
+        The stacklevel. Minimum of 2.
     """
-    pass
+    # Count number of wrappers around `func`
+    wrapped_count = _count_wrappers(func)
 
-
-def _get_stack_rank(func):
-    """Return function rank in the call stack."""
-    if _is_wrapped(func):
-        return 1 + _get_stack_rank(func.__wrapped__)
+    # Count number of total wrappers around global version of `func`
+    module = sys.modules.get(func.__module__)
+    try:
+        for name in func.__qualname__.split("."):
+            global_func = getattr(module, name)
+    except AttributeError as e:
+        raise RuntimeError(
+            f"Could not access `{func.__qualname__}` in {module!r}, "
+            f" may be a closure. Set stacklevel manually. ",
+        ) from e
     else:
-        return 0
+        global_wrapped_count = _count_wrappers(global_func)
 
-
-def _is_wrapped(func):
-    return "__wrapped__" in dir(func)
+    stacklevel = global_wrapped_count - wrapped_count + 1
+    return max(stacklevel, 2)
 
 
 def _get_stack_length(func):
     """Return function call stack length."""
-    return _get_stack_rank(func.__globals__.get(func.__name__, func))
+    _func = func.__globals__.get(func.__name__, func)
+    length = _count_wrappers(_func)
+    return length
 
 
 class _DecoratorBaseClass:
@@ -56,8 +90,8 @@ class _DecoratorBaseClass:
     _stack_length = {}
 
     def get_stack_length(self, func):
-        return self._stack_length.get(func.__name__,
-                                      _get_stack_length(func))
+        length = self._stack_length.get(func.__name__, _get_stack_length(func))
+        return length
 
 
 class change_default_value(_DecoratorBaseClass):
@@ -77,8 +111,7 @@ class change_default_value(_DecoratorBaseClass):
 
     """
 
-    def __init__(self, arg_name, *, new_value, changed_version,
-                 warning_msg=None):
+    def __init__(self, arg_name, *, new_value, changed_version, warning_msg=None):
         self.arg_name = arg_name
         self.new_value = new_value
         self.warning_msg = warning_msg
@@ -89,7 +122,7 @@ class change_default_value(_DecoratorBaseClass):
         arg_idx = list(parameters.keys()).index(self.arg_name)
         old_value = parameters[self.arg_name].default
 
-        stack_rank = _get_stack_rank(func)
+        stack_rank = _count_wrappers(func)
 
         if self.warning_msg is None:
             self.warning_msg = (
@@ -98,77 +131,214 @@ class change_default_value(_DecoratorBaseClass):
                 f'the default {self.arg_name} value is {old_value}. '
                 f'From version {self.changed_version}, the {self.arg_name} '
                 f'default value will be {self.new_value}. To avoid '
-                f'this warning, please explicitly set {self.arg_name} value.')
+                f'this warning, please explicitly set {self.arg_name} value.'
+            )
 
         @functools.wraps(func)
         def fixed_func(*args, **kwargs):
             stacklevel = 1 + self.get_stack_length(func) - stack_rank
             if len(args) < arg_idx + 1 and self.arg_name not in kwargs.keys():
                 # warn that arg_name default value changed:
-                warnings.warn(self.warning_msg, FutureWarning,
-                              stacklevel=stacklevel)
+                warnings.warn(self.warning_msg, FutureWarning, stacklevel=stacklevel)
             return func(*args, **kwargs)
 
         return fixed_func
 
 
-class remove_arg(_DecoratorBaseClass):
-    """Decorator to remove an argument from function's signature.
+class PatchClassRepr(type):
+    """Control class representations in rendered signatures."""
+
+    def __repr__(cls):
+        return f"<{cls.__name__}>"
+
+
+class DEPRECATED(metaclass=PatchClassRepr):
+    """Signal value to help with deprecating parameters that use None.
+
+    This is a proxy object, used to signal that a parameter has not been set.
+    This is useful if ``None`` is already used for a different purpose or just
+    to highlight a deprecated parameter in the signature.
+    """
+
+
+class deprecate_parameter:
+    """Deprecate a parameter of a function.
 
     Parameters
     ----------
-    arg_name: str
-        The name of the argument to be removed.
-    changed_version : str
+    deprecated_name : str
+        The name of the deprecated parameter.
+    start_version : str
+        The package version in which the warning was introduced.
+    stop_version : str
         The package version in which the warning will be replaced by
-        an error.
-    help_msg: str
-        Optional message appended to the generic warning message.
+        an error / the deprecation is completed.
+    template : str, optional
+        If given, this message template is used instead of the default one.
+    new_name : str, optional
+        If given, the default message will recommend the new parameter name and an
+        error will be raised if the user uses both old and new names for the
+        same parameter.
+    modify_docstring : bool, optional
+        If the wrapped function has a docstring, add the deprecated parameters
+        to the "Other Parameters" section.
+    stacklevel : int, optional
+        This decorator attempts to detect the appropriate stacklevel for the
+        deprecation warning automatically. If this fails, e.g., due to
+        decorating a closure, you can set the stacklevel manually. The
+        outermost decorator should have stacklevel 2, the next inner one
+        stacklevel 3, etc.
 
+    Notes
+    -----
+    Assign `DEPRECATED` as the new default value for the deprecated parameter.
+    This marks the status of the parameter also in the signature and rendered
+    HTML docs.
+
+    This decorator can be stacked to deprecate more than one parameter.
+
+    Examples
+    --------
+    >>> from skimage._shared.utils import deprecate_parameter, DEPRECATED
+    >>> @deprecate_parameter(
+    ...     "b", new_name="c", start_version="0.1", stop_version="0.3"
+    ... )
+    ... def foo(a, b=DEPRECATED, *, c=None):
+    ...     return a, c
+
+    Calling ``foo(1, b=2)``  will warn with::
+
+        FutureWarning: Parameter `b` is deprecated since version 0.1 and will
+        be removed in 0.3 (or later). To avoid this warning, please use the
+        parameter `c` instead. For more details, see the documentation of
+        `foo`.
     """
 
-    def __init__(self, arg_name, *, changed_version, help_msg=None):
-        self.arg_name = arg_name
-        self.help_msg = help_msg
-        self.changed_version = changed_version
+    DEPRECATED = DEPRECATED  # Make signal value accessible for convenience
+
+    remove_parameter_template = (
+        "Parameter `{deprecated_name}` is deprecated since version "
+        "{deprecated_version} and will be removed in {changed_version} (or "
+        "later). To avoid this warning, please do not use the parameter "
+        "`{deprecated_name}`. For more details, see the documentation of "
+        "`{func_name}`."
+    )
+
+    replace_parameter_template = (
+        "Parameter `{deprecated_name}` is deprecated since version "
+        "{deprecated_version} and will be removed in {changed_version} (or "
+        "later). To avoid this warning, please use the parameter `{new_name}` "
+        "instead. For more details, see the documentation of `{func_name}`."
+    )
+
+    def __init__(
+        self,
+        deprecated_name,
+        *,
+        start_version,
+        stop_version,
+        template=None,
+        new_name=None,
+        modify_docstring=True,
+        stacklevel=None,
+    ):
+        self.deprecated_name = deprecated_name
+        self.new_name = new_name
+        self.template = template
+        self.start_version = start_version
+        self.stop_version = stop_version
+        self.modify_docstring = modify_docstring
+        self.stacklevel = stacklevel
 
     def __call__(self, func):
-
         parameters = inspect.signature(func).parameters
-        arg_idx = list(parameters.keys()).index(self.arg_name)
-        warning_msg = (
-            f'{self.arg_name} argument is deprecated and will be removed '
-            f'in version {self.changed_version}. To avoid this warning, '
-            f'please do not use the {self.arg_name} argument. Please '
-            f'see {func.__name__} documentation for more details.')
+        deprecated_idx = list(parameters.keys()).index(self.deprecated_name)
+        if self.new_name:
+            new_idx = list(parameters.keys()).index(self.new_name)
+        else:
+            new_idx = False
 
-        if self.help_msg is not None:
-            warning_msg += f' {self.help_msg}'
+        if parameters[self.deprecated_name].default is not DEPRECATED:
+            raise RuntimeError(
+                f"Expected `{self.deprecated_name}` to have the value {DEPRECATED!r} "
+                f"to indicate its status in the rendered signature."
+            )
 
-        stack_rank = _get_stack_rank(func)
+        if self.template is not None:
+            template = self.template
+        elif self.new_name is not None:
+            template = self.replace_parameter_template
+        else:
+            template = self.remove_parameter_template
+        warning_message = template.format(
+            deprecated_name=self.deprecated_name,
+            deprecated_version=self.start_version,
+            changed_version=self.stop_version,
+            func_name=func.__qualname__,
+            new_name=self.new_name,
+        )
 
         @functools.wraps(func)
         def fixed_func(*args, **kwargs):
-            stacklevel = 1 + self.get_stack_length(func) - stack_rank
-            if len(args) > arg_idx or self.arg_name in kwargs.keys():
-                # warn that arg_name is deprecated
-                warnings.warn(warning_msg, FutureWarning,
-                              stacklevel=stacklevel)
+            deprecated_value = DEPRECATED
+            new_value = DEPRECATED
+
+            # Extract value of deprecated parameter
+            if len(args) > deprecated_idx:
+                deprecated_value = args[deprecated_idx]
+                args = (
+                    args[:deprecated_idx] + (DEPRECATED,) + args[deprecated_idx + 1 :]
+                )
+            if self.deprecated_name in kwargs.keys():
+                deprecated_value = kwargs[self.deprecated_name]
+                kwargs[self.deprecated_name] = DEPRECATED
+            # Extract value of new parameter (if present)
+            if new_idx is not False and len(args) > new_idx:
+                new_value = args[new_idx]
+            if self.new_name and self.new_name in kwargs.keys():
+                new_value = kwargs[self.new_name]
+
+            if deprecated_value is not DEPRECATED:
+                stacklevel = (
+                    self.stacklevel
+                    if self.stacklevel is not None
+                    else _warning_stacklevel(func)
+                )
+                warnings.warn(
+                    warning_message, category=FutureWarning, stacklevel=stacklevel
+                )
+
+                if new_value is not DEPRECATED:
+                    raise ValueError(
+                        f"Both deprecated parameter `{self.deprecated_name}` "
+                        f"and new parameter `{self.new_name}` are used. Use "
+                        f"only the latter to avoid conflicting values."
+                    )
+                elif self.new_name is not None:
+                    # Assign old value to new one
+                    kwargs[self.new_name] = deprecated_value
+
             return func(*args, **kwargs)
 
+        if self.modify_docstring and func.__doc__ is not None:
+            newdoc = _docstring_add_deprecated(
+                func, {self.deprecated_name: self.new_name}, self.start_version
+            )
+            fixed_func.__doc__ = newdoc
+
         return fixed_func
 
 
-def docstring_add_deprecated(func, kwarg_mapping, deprecated_version):
+def _docstring_add_deprecated(func, kwarg_mapping, deprecated_version):
     """Add deprecated kwarg(s) to the "Other Params" section of a docstring.
 
     Parameters
-    ---------
+    ----------
     func : function
         The function whose docstring we wish to update.
     kwarg_mapping : dict
-        A dict containing {old_arg: new_arg} key/value pairs as used by
-        `deprecate_kwarg`.
+        A dict containing {old_arg: new_arg} key/value pairs, see
+        `deprecate_parameter`.
     deprecated_version : str
         A major.minor version string specifying when old_arg was
         deprecated.
@@ -189,13 +359,15 @@ def docstring_add_deprecated(func, kwarg_mapping, deprecated_version):
 
     Doc = FunctionDoc(func)
     for old_arg, new_arg in kwarg_mapping.items():
-        desc = [f'Deprecated in favor of `{new_arg}`.',
-                f'',
-                f'.. deprecated:: {deprecated_version}']
+        desc = []
+        if new_arg is None:
+            desc.append(f'`{old_arg}` is deprecated.')
+        else:
+            desc.append(f'Deprecated in favor of `{new_arg}`.')
+
+        desc += ['', f'.. deprecated:: {deprecated_version}']
         Doc['Other Parameters'].append(
-            Parameter(name=old_arg,
-                      type='DEPRECATED',
-                      desc=desc)
+            Parameter(name=old_arg, type='DEPRECATED', desc=desc)
         )
     new_docstring = str(Doc)
 
@@ -219,141 +391,10 @@ def docstring_add_deprecated(func, kwarg_mapping, deprecated_version):
     # '\n    ' rather than '\n' here to restore the original indentation.
     final_docstring = descr + '\n    '.join(no_header)
     # strip any extra spaces from ends of lines
-    final_docstring = '\n'.join(
-        [line.rstrip() for line in final_docstring.split('\n')]
-    )
+    final_docstring = '\n'.join([line.rstrip() for line in final_docstring.split('\n')])
     return final_docstring
 
 
-class deprecate_kwarg(_DecoratorBaseClass):
-    """Decorator ensuring backward compatibility when argument names are
-    modified in a function definition.
-
-    Parameters
-    ----------
-    kwarg_mapping: dict
-        Mapping between the function's old argument names and the new
-        ones.
-    deprecated_version : str
-        The package version in which the argument was first deprecated.
-    warning_msg: str
-        Optional warning message. If None, a generic warning message
-        is used.
-    removed_version : str
-        The package version in which the deprecated argument will be
-        removed.
-
-    """
-
-    def __init__(self, kwarg_mapping, deprecated_version, warning_msg=None,
-                 removed_version=None):
-        self.kwarg_mapping = kwarg_mapping
-        if warning_msg is None:
-            self.warning_msg = ("`{old_arg}` is a deprecated argument name "
-                                "for `{func_name}`. ")
-            if removed_version is not None:
-                self.warning_msg += (f'It will be removed in '
-                                     f'version {removed_version}. ')
-            self.warning_msg += "Please use `{new_arg}` instead."
-        else:
-            self.warning_msg = warning_msg
-
-        self.deprecated_version = deprecated_version
-
-    def __call__(self, func):
-
-        stack_rank = _get_stack_rank(func)
-
-        @functools.wraps(func)
-        def fixed_func(*args, **kwargs):
-            stacklevel = 1 + self.get_stack_length(func) - stack_rank
-
-            for old_arg, new_arg in self.kwarg_mapping.items():
-                if old_arg in kwargs:
-                    #  warn that the function interface has changed:
-                    warnings.warn(self.warning_msg.format(
-                        old_arg=old_arg, func_name=func.__name__,
-                        new_arg=new_arg), FutureWarning,
-                        stacklevel=stacklevel)
-                    # Substitute new_arg to old_arg
-                    kwargs[new_arg] = kwargs.pop(old_arg)
-
-            # Call the function with the fixed arguments
-            return func(*args, **kwargs)
-
-        if func.__doc__ is not None:
-            newdoc = docstring_add_deprecated(func, self.kwarg_mapping,
-                                              self.deprecated_version)
-            fixed_func.__doc__ = newdoc
-        return fixed_func
-
-
-class deprecate_multichannel_kwarg(deprecate_kwarg):
-    """Decorator for deprecating multichannel keyword in favor of channel_axis.
-
-    Parameters
-    ----------
-    removed_version : str
-        The package version in which the deprecated argument will be
-        removed.
-
-    """
-
-    def __init__(self, removed_version='1.0', multichannel_position=None):
-        super().__init__(
-            kwarg_mapping={'multichannel': 'channel_axis'},
-            deprecated_version='0.19',
-            warning_msg=None,
-            removed_version=removed_version)
-        self.position = multichannel_position
-
-    def __call__(self, func):
-
-        stack_rank = _get_stack_rank(func)
-
-        @functools.wraps(func)
-        def fixed_func(*args, **kwargs):
-            stacklevel = 1 + self.get_stack_length(func) - stack_rank
-
-            if self.position is not None and len(args) > self.position:
-                warning_msg = (
-                    "Providing the `multichannel` argument positionally to "
-                    "{func_name} is deprecated. Use the `channel_axis` kwarg "
-                    "instead."
-                )
-                warnings.warn(warning_msg.format(func_name=func.__name__),
-                              FutureWarning,
-                              stacklevel=stacklevel)
-                if 'channel_axis' in kwargs:
-                    raise ValueError(
-                        "Cannot provide both a `channel_axis` kwarg and a "
-                        "positional `multichannel` value."
-                    )
-                else:
-                    channel_axis = -1 if args[self.position] else None
-                    kwargs['channel_axis'] = channel_axis
-
-            if 'multichannel' in kwargs:
-                #  warn that the function interface has changed:
-                warnings.warn(self.warning_msg.format(
-                    old_arg='multichannel', func_name=func.__name__,
-                    new_arg='channel_axis'), FutureWarning,
-                    stacklevel=stacklevel)
-
-                # multichannel = True -> last axis corresponds to channels
-                convert = {True: -1, False: None}
-                kwargs['channel_axis'] = convert[kwargs.pop('multichannel')]
-
-            # Call the function with the fixed arguments
-            return func(*args, **kwargs)
-
-        if func.__doc__ is not None:
-            newdoc = docstring_add_deprecated(
-                func, {'multichannel': 'channel_axis'}, '0.19')
-            fixed_func.__doc__ = newdoc
-        return fixed_func
-
-
 class channel_as_last_axis:
     """Decorator for automatically making channels axis last for all arrays.
 
@@ -377,17 +418,20 @@ class channel_as_last_axis:
         where some or all are multichannel.
 
     """
-    def __init__(self, channel_arg_positions=(0,), channel_kwarg_names=(),
-                 multichannel_output=True):
+
+    def __init__(
+        self,
+        channel_arg_positions=(0,),
+        channel_kwarg_names=(),
+        multichannel_output=True,
+    ):
         self.arg_positions = set(channel_arg_positions)
         self.kwarg_names = set(channel_kwarg_names)
         self.multichannel_output = multichannel_output
 
     def __call__(self, func):
-
         @functools.wraps(func)
         def fixed_func(*args, **kwargs):
-
             channel_axis = kwargs.get('channel_axis', None)
 
             if channel_axis is None:
@@ -399,8 +443,7 @@ class channel_as_last_axis:
             if np.isscalar(channel_axis):
                 channel_axis = (channel_axis,)
             if len(channel_axis) > 1:
-                raise ValueError(
-                    "only a single channel axis is currently suported")
+                raise ValueError("only a single channel axis is currently supported")
 
             if channel_axis == (-1,) or channel_axis == -1:
                 return func(*args, **kwargs)
@@ -432,55 +475,63 @@ class channel_as_last_axis:
         return fixed_func
 
 
-class deprecated:
-    """Decorator to mark deprecated functions with warning.
+class deprecate_func(_DecoratorBaseClass):
+    """Decorate a deprecated function and warn when it is called.
 
     Adapted from <http://wiki.python.org/moin/PythonDecoratorLibrary>.
 
     Parameters
     ----------
-    alt_func : str
-        If given, tell user what function to use instead.
-    behavior : {'warn', 'raise'}
-        Behavior during call to deprecated function: 'warn' = warn user that
-        function is deprecated; 'raise' = raise error.
+    deprecated_version : str
+        The package version when the deprecation was introduced.
     removed_version : str
         The package version in which the deprecated function will be removed.
+    hint : str, optional
+        A hint on how to address this deprecation,
+        e.g., "Use `skimage.submodule.alternative_func` instead."
+
+    Examples
+    --------
+    >>> @deprecate_func(
+    ...     deprecated_version="1.0.0",
+    ...     removed_version="1.2.0",
+    ...     hint="Use `bar` instead."
+    ... )
+    ... def foo():
+    ...     pass
+
+    Calling ``foo`` will warn with::
+
+        FutureWarning: `foo` is deprecated since version 1.0.0
+        and will be removed in version 1.2.0. Use `bar` instead.
     """
 
-    def __init__(self, alt_func=None, behavior='warn', removed_version=None):
-        self.alt_func = alt_func
-        self.behavior = behavior
+    def __init__(self, *, deprecated_version, removed_version=None, hint=None):
+        self.deprecated_version = deprecated_version
         self.removed_version = removed_version
+        self.hint = hint
 
     def __call__(self, func):
+        message = (
+            f"`{func.__name__}` is deprecated since version "
+            f"{self.deprecated_version}"
+        )
+        if self.removed_version:
+            message += f" and will be removed in version {self.removed_version}."
+        if self.hint:
+            # Prepend space and make sure it closes with "."
+            message += f" {self.hint.rstrip('.')}."
 
-        alt_msg = ''
-        if self.alt_func is not None:
-            alt_msg = ' Use ``%s`` instead.' % self.alt_func
-        rmv_msg = ''
-        if self.removed_version is not None:
-            rmv_msg = (' and will be removed in version %s' %
-                       self.removed_version)
-
-        msg = ('Function ``%s`` is deprecated' % func.__name__ +
-               rmv_msg + '.' + alt_msg)
+        stack_rank = _count_wrappers(func)
 
         @functools.wraps(func)
         def wrapped(*args, **kwargs):
-            if self.behavior == 'warn':
-                func_code = func.__code__
-                warnings.simplefilter('always', skimage_deprecation)
-                warnings.warn_explicit(msg,
-                                       category=skimage_deprecation,
-                                       filename=func_code.co_filename,
-                                       lineno=func_code.co_firstlineno + 1)
-            elif self.behavior == 'raise':
-                raise skimage_deprecation(msg)
+            stacklevel = 1 + self.get_stack_length(func) - stack_rank
+            warnings.warn(message, category=FutureWarning, stacklevel=stacklevel)
             return func(*args, **kwargs)
 
-        # modify doc string to display deprecation warning
-        doc = '**Deprecated function**.' + alt_msg
+        # modify docstring to display deprecation warning
+        doc = f'**Deprecated:** {message}'
         if wrapped.__doc__ is None:
             wrapped.__doc__ = doc
         else:
@@ -490,9 +541,7 @@ class deprecated:
 
 
 def get_bound_method_class(m):
-    """Return the class for a bound method.
-
-    """
+    """Return the class for a bound method."""
     return m.im_class if sys.version < '3' else m.__self__.__class__
 
 
@@ -545,27 +594,29 @@ def safe_as_int(val, atol=1e-3):
     53
 
     """
-    mod = np.asarray(val) % 1                # Extract mantissa
+    mod = np.asarray(val) % 1  # Extract mantissa
 
     # Check for and subtract any mod values > 0.5 from 1
-    if mod.ndim == 0:                        # Scalar input, cannot be indexed
+    if mod.ndim == 0:  # Scalar input, cannot be indexed
         if mod > 0.5:
             mod = 1 - mod
-    else:                                    # Iterable input, now ndarray
+    else:  # Iterable input, now ndarray
         mod[mod > 0.5] = 1 - mod[mod > 0.5]  # Test on each side of nearest int
 
     try:
         np.testing.assert_allclose(mod, 0, atol=atol)
     except AssertionError:
-        raise ValueError(f'Integer argument required but received '
-                         f'{val}, check inputs.')
+        raise ValueError(
+            f'Integer argument required but received ' f'{val}, check inputs.'
+        )
 
     return np.round(val).astype(np.int64)
 
 
-def check_shape_equality(im1, im2):
-    """Raise an error if the shape do not match."""
-    if not im1.shape == im2.shape:
+def check_shape_equality(*images):
+    """Check that all images have the same shape"""
+    image0 = images[0]
+    if not all(image0.shape == image.shape for image in images[1:]):
         raise ValueError('Input images must have the same dimensions.')
     return
 
@@ -688,6 +739,7 @@ def convert_to_float(image, preserve_range):
             image = image.astype(float)
     else:
         from ..util.dtype import img_as_float
+
         image = img_as_float(image)
     return image
 
@@ -717,22 +769,21 @@ def _validate_interpolation_order(image_dtype, order):
         return 0 if image_dtype == bool else 1
 
     if order < 0 or order > 5:
-        raise ValueError("Spline interpolation order has to be in the "
-                         "range 0-5.")
+        raise ValueError("Spline interpolation order has to be in the " "range 0-5.")
 
     if image_dtype == bool and order != 0:
         raise ValueError(
             "Input image dtype is bool. Interpolation is not defined "
-             "with bool data type. Please set order to 0 or explicitely "
-             "cast input image to another data type.")
+            "with bool data type. Please set order to 0 or explicitly "
+            "cast input image to another data type."
+        )
 
     return order
 
 
 def _to_np_mode(mode):
     """Convert padding modes from `ndi.correlate` to `np.pad`."""
-    mode_translation_dict = dict(nearest='edge', reflect='symmetric',
-                                 mirror='reflect')
+    mode_translation_dict = dict(nearest='edge', reflect='symmetric', mirror='reflect')
     if mode in mode_translation_dict:
         mode = mode_translation_dict[mode]
     return mode
@@ -740,15 +791,20 @@ def _to_np_mode(mode):
 
 def _to_ndimage_mode(mode):
     """Convert from `numpy.pad` mode name to the corresponding ndimage mode."""
-    mode_translation_dict = dict(constant='constant', edge='nearest',
-                                 symmetric='reflect', reflect='mirror',
-                                 wrap='wrap')
+    mode_translation_dict = dict(
+        constant='constant',
+        edge='nearest',
+        symmetric='reflect',
+        reflect='mirror',
+        wrap='wrap',
+    )
     if mode not in mode_translation_dict:
         raise ValueError(
-            (f"Unknown mode: '{mode}', or cannot translate mode. The "
-             f"mode should be one of 'constant', 'edge', 'symmetric', "
-             f"'reflect', or 'wrap'. See the documentation of numpy.pad for "
-             f"more info."))
+            f"Unknown mode: '{mode}', or cannot translate mode. The "
+            f"mode should be one of 'constant', 'edge', 'symmetric', "
+            f"'reflect', or 'wrap'. See the documentation of numpy.pad for "
+            f"more info."
+        )
     return _fix_ndimage_mode(mode_translation_dict[mode])
 
 
@@ -756,9 +812,7 @@ def _fix_ndimage_mode(mode):
     # SciPy 1.6.0 introduced grid variants of constant and wrap which
     # have less surprising behavior for images. Use these when available
     grid_modes = {'constant': 'grid-constant', 'wrap': 'grid-wrap'}
-    if NumpyVersion(scipy.__version__) >= '1.6.0':
-        mode = grid_modes.get(mode, mode)
-    return mode
+    return grid_modes.get(mode, mode)
 
 
 new_float_type = {
@@ -769,8 +823,8 @@ new_float_type = {
     np.complex128().dtype.char: np.complex128,
     # altered types
     np.float16().dtype.char: np.float32,
-    'g': np.float64,      # np.float128 ; doesn't exist on windows
-    'G': np.complex128,   # np.complex256 ; doesn't exist on windows
+    'g': np.float64,  # np.float128 ; doesn't exist on windows
+    'G': np.complex128,  # np.complex256 ; doesn't exist on windows
 }
 
 
@@ -784,8 +838,8 @@ def _supported_float_type(input_dtype, allow_complex=False):
 
     Parameters
     ----------
-    input_dtype : np.dtype or Iterable of np.dtype
-        The input dtype. If a sequence of multiple dtypes is provided, each
+    input_dtype : np.dtype or tuple of np.dtype
+        The input dtype. If a tuple of multiple dtypes is provided, each
         dtype is first converted to a supported floating point type and the
         final dtype is then determined by applying `np.result_type` on the
         sequence of supported floating point types.
@@ -797,7 +851,7 @@ def _supported_float_type(input_dtype, allow_complex=False):
     float_type : dtype
         Floating-point dtype for the image.
     """
-    if isinstance(input_dtype, Iterable) and not isinstance(input_dtype, str):
+    if isinstance(input_dtype, tuple):
         return np.result_type(*(_supported_float_type(d) for d in input_dtype))
     input_dtype = np.dtype(input_dtype)
     if not allow_complex and input_dtype.kind == 'c':
@@ -808,3 +862,23 @@ def _supported_float_type(input_dtype, allow_complex=False):
 def identity(image, *args, **kwargs):
     """Returns the first argument unmodified."""
     return image
+
+
+def as_binary_ndarray(array, *, variable_name):
+    """Return `array` as a numpy.ndarray of dtype bool.
+
+    Raises
+    ------
+    ValueError:
+        An error including the given `variable_name` if `array` can not be
+        safely cast to a boolean array.
+    """
+    array = np.asarray(array)
+    if array.dtype != bool:
+        if np.any((array != 1) & (array != 0)):
+            raise ValueError(
+                f"{variable_name} array is not of dtype boolean or "
+                f"contains values other than 0 and 1 so cannot be "
+                f"safely cast to boolean array."
+            )
+    return np.asarray(array, dtype=bool)
