@@ -3,8 +3,9 @@ import numpy as np
 from .._shared.filters import gaussian
 
 
-def binary_blobs(length=512, blob_size_fraction=0.1, n_dim=2,
-                 volume_fraction=0.5, seed=None):
+def binary_blobs(
+    length=512, blob_size_fraction=0.1, n_dim=2, volume_fraction=0.5, rng=None
+):
     """
     Generate synthetic binary image with several rounded blob-like objects.
 
@@ -20,12 +21,10 @@ def binary_blobs(length=512, blob_size_fraction=0.1, n_dim=2,
     volume_fraction : float, default 0.5
         Fraction of image pixels covered by the blobs (where the output is 1).
         Should be in [0, 1].
-    seed : {None, int, `numpy.random.Generator`}, optional
-        If `seed` is None the `numpy.random.Generator` singleton is used.
-        If `seed` is an int, a new ``Generator`` instance is used,
-        seeded with `seed`.
-        If `seed` is already a ``Generator`` instance then that instance is
-        used.
+    rng : {`numpy.random.Generator`, int}, optional
+        Pseudo-random number generator.
+        By default, a PCG64 generator is used (see :func:`numpy.random.default_rng`).
+        If `rng` is an int, it is used to seed the generator.
 
     Returns
     -------
@@ -48,16 +47,15 @@ def binary_blobs(length=512, blob_size_fraction=0.1, n_dim=2,
     >>> blobs = data.binary_blobs(length=256, volume_fraction=0.3)
 
     """
-    # filters is quite an expensive import since it imports all of scipy.signal
-    # We lazy import here
 
-    rs = np.random.default_rng(seed)
+    rs = np.random.default_rng(rng)
     shape = tuple([length] * n_dim)
     mask = np.zeros(shape)
-    n_pts = max(int(1. / blob_size_fraction) ** n_dim, 1)
+    n_pts = max(int(1.0 / blob_size_fraction) ** n_dim, 1)
     points = (length * rs.random((n_dim, n_pts))).astype(int)
     mask[tuple(indices for indices in points)] = 1
-    mask = gaussian(mask, sigma=0.25 * length * blob_size_fraction,
-                    preserve_range=False)
+    mask = gaussian(
+        mask, sigma=0.25 * length * blob_size_fraction, preserve_range=False
+    )
     threshold = np.percentile(mask, 100 * (1 - volume_fraction))
     return np.logical_not(mask < threshold)
