@@ -10,7 +10,7 @@ def shannon_entropy(image, base=2):
 
     Parameters
     ----------
-    image : (N, M) ndarray
+    image : (M, N) ndarray
         Grayscale input image.
     base : float, optional
         The logarithmic base to use.
@@ -32,8 +32,9 @@ def shannon_entropy(image, base=2):
     Examples
     --------
     >>> from skimage import data
+    >>> from skimage.measure import shannon_entropy
     >>> shannon_entropy(data.camera())
-    7.047955232423086
+    7.231695011055706
     """
 
     _, counts = unique(image, return_counts=True)
