@@ -20,10 +20,10 @@ def radon(image, theta=None, circle=True, *, preserve_range=False):
 
     Parameters
     ----------
-    image : array_like
+    image : ndarray
         Input image. The rotation axis will be located in the pixel with
         indices ``(image.shape[0] // 2, image.shape[1] // 2)``.
-    theta : array_like, optional
+    theta : array, optional
         Projection angles (in degrees). If `None`, the value is set to
         np.arange(180).
     circle : boolean, optional
@@ -67,18 +67,23 @@ def radon(image, theta=None, circle=True, *, preserve_range=False):
         shape_min = min(image.shape)
         radius = shape_min // 2
         img_shape = np.array(image.shape)
-        coords = np.array(np.ogrid[:image.shape[0], :image.shape[1]],
-                          dtype=object)
+        coords = np.array(np.ogrid[: image.shape[0], : image.shape[1]], dtype=object)
         dist = ((coords - img_shape // 2) ** 2).sum(0)
-        outside_reconstruction_circle = dist > radius ** 2
+        outside_reconstruction_circle = dist > radius**2
         if np.any(image[outside_reconstruction_circle]):
-            warn('Radon transform: image must be zero outside the '
-                 'reconstruction circle')
+            warn(
+                'Radon transform: image must be zero outside the '
+                'reconstruction circle'
+            )
         # Crop image to make it square
-        slices = tuple(slice(int(np.ceil(excess / 2)),
-                             int(np.ceil(excess / 2) + shape_min))
-                       if excess > 0 else slice(None)
-                       for excess in (img_shape - shape_min))
+        slices = tuple(
+            (
+                slice(int(np.ceil(excess / 2)), int(np.ceil(excess / 2) + shape_min))
+                if excess > 0
+                else slice(None)
+            )
+            for excess in (img_shape - shape_min)
+        )
         padded_image = image[slices]
     else:
         diagonal = np.sqrt(2) * max(image.shape)
@@ -87,21 +92,23 @@ def radon(image, theta=None, circle=True, *, preserve_range=False):
         old_center = [s // 2 for s in image.shape]
         pad_before = [nc - oc for oc, nc in zip(old_center, new_center)]
         pad_width = [(pb, p - pb) for pb, p in zip(pad_before, pad)]
-        padded_image = np.pad(image, pad_width, mode='constant',
-                              constant_values=0)
+        padded_image = np.pad(image, pad_width, mode='constant', constant_values=0)
 
     # padded_image is always square
     if padded_image.shape[0] != padded_image.shape[1]:
         raise ValueError('padded_image must be a square')
     center = padded_image.shape[0] // 2
-    radon_image = np.zeros((padded_image.shape[0], len(theta)),
-                           dtype=image.dtype)
+    radon_image = np.zeros((padded_image.shape[0], len(theta)), dtype=image.dtype)
 
     for i, angle in enumerate(np.deg2rad(theta)):
         cos_a, sin_a = np.cos(angle), np.sin(angle)
-        R = np.array([[cos_a, sin_a, -center * (cos_a + sin_a - 1)],
-                      [-sin_a, cos_a, -center * (cos_a - sin_a - 1)],
-                      [0, 0, 1]])
+        R = np.array(
+            [
+                [cos_a, sin_a, -center * (cos_a + sin_a - 1)],
+                [-sin_a, cos_a, -center * (cos_a - sin_a - 1)],
+                [0, 0, 1],
+            ]
+        )
         rotated = warp(padded_image, R, clip=False)
         radon_image[:, i] = rotated.sum(0)
     return radon_image
@@ -143,8 +150,12 @@ def _get_fourier_filter(size, filter_name):
            Imaging", IEEE Press 1988.
 
     """
-    n = np.concatenate((np.arange(1, size / 2 + 1, 2, dtype=int),
-                        np.arange(size / 2 - 1, 0, -2, dtype=int)))
+    n = np.concatenate(
+        (
+            np.arange(1, size / 2 + 1, 2, dtype=int),
+            np.arange(size / 2 - 1, 0, -2, dtype=int),
+        )
+    )
     f = np.zeros(size)
     f[0] = 0.25
     f[1::2] = -1 / (np.pi * n) ** 2
@@ -152,7 +163,7 @@ def _get_fourier_filter(size, filter_name):
     # Computing the ramp filter from the fourier transform of its
     # frequency domain representation lessens artifacts and removes a
     # small bias as explained in [1], Chap 3. Equation 61
-    fourier_filter = 2 * np.real(fft(f))         # ramp filter
+    fourier_filter = 2 * np.real(fft(f))  # ramp filter
     if filter_name == "ramp":
         pass
     elif filter_name == "shepp-logan":
@@ -173,9 +184,15 @@ def _get_fourier_filter(size, filter_name):
     return fourier_filter[:, np.newaxis]
 
 
-def iradon(radon_image, theta=None, output_size=None,
-           filter_name="ramp", interpolation="linear", circle=True,
-           preserve_range=True):
+def iradon(
+    radon_image,
+    theta=None,
+    output_size=None,
+    filter_name="ramp",
+    interpolation="linear",
+    circle=True,
+    preserve_range=True,
+):
     """Inverse radon transform.
 
     Reconstruct an image from the radon transform, using the filtered
@@ -183,13 +200,13 @@ def iradon(radon_image, theta=None, output_size=None,
 
     Parameters
     ----------
-    radon_image : array
+    radon_image : ndarray
         Image containing radon transform (sinogram). Each column of
         the image corresponds to a projection along a different
         angle. The tomography rotation axis should lie at the pixel
         index ``radon_image.shape[0] // 2`` along the 0th dimension of
         ``radon_image``.
-    theta : array_like, optional
+    theta : array, optional
         Reconstruction angles (in degrees). Default: m angles evenly spaced
         between 0 and 180 (if the shape of `radon_image` is (N, M)).
     output_size : int, optional
@@ -244,16 +261,18 @@ def iradon(radon_image, theta=None, output_size=None,
 
     angles_count = len(theta)
     if angles_count != radon_image.shape[1]:
-        raise ValueError("The given ``theta`` does not match the number of "
-                         "projections in ``radon_image``.")
+        raise ValueError(
+            "The given ``theta`` does not match the number of "
+            "projections in ``radon_image``."
+        )
 
     interpolation_types = ('linear', 'nearest', 'cubic')
     if interpolation not in interpolation_types:
-        raise ValueError("Unknown interpolation: %s" % interpolation)
+        raise ValueError(f"Unknown interpolation: {interpolation}")
 
     filter_types = ('ramp', 'shepp-logan', 'cosine', 'hamming', 'hann', None)
     if filter_name not in filter_types:
-        raise ValueError("Unknown filter: %s" % filter_name)
+        raise ValueError(f"Unknown filter: {filter_name}")
 
     radon_image = convert_to_float(radon_image, preserve_range)
     dtype = radon_image.dtype
@@ -282,8 +301,7 @@ def iradon(radon_image, theta=None, output_size=None,
     radon_filtered = np.real(ifft(projection, axis=0)[:img_shape, :])
 
     # Reconstruct image by interpolation
-    reconstructed = np.zeros((output_size, output_size),
-                             dtype=dtype)
+    reconstructed = np.zeros((output_size, output_size), dtype=dtype)
     radius = output_size // 2
     xpr, ypr = np.mgrid[:output_size, :output_size] - radius
     x = np.arange(img_shape) - img_shape // 2
@@ -293,13 +311,14 @@ def iradon(radon_image, theta=None, output_size=None,
         if interpolation == 'linear':
             interpolant = partial(np.interp, xp=x, fp=col, left=0, right=0)
         else:
-            interpolant = interp1d(x, col, kind=interpolation,
-                                   bounds_error=False, fill_value=0)
+            interpolant = interp1d(
+                x, col, kind=interpolation, bounds_error=False, fill_value=0
+            )
         reconstructed += interpolant(t)
 
     if circle:
-        out_reconstruction_circle = (xpr ** 2 + ypr ** 2) > radius ** 2
-        reconstructed[out_reconstruction_circle] = 0.
+        out_reconstruction_circle = (xpr**2 + ypr**2) > radius**2
+        reconstructed[out_reconstruction_circle] = 0.0
 
     return reconstructed * np.pi / (2 * angles_count)
 
@@ -310,7 +329,7 @@ def order_angles_golden_ratio(theta):
 
     Parameters
     ----------
-    theta : 1D array of floats
+    theta : array of floats, shape (M,)
         Projection angles in degrees. Duplicate angles are not allowed.
 
     Returns
@@ -338,12 +357,12 @@ def order_angles_golden_ratio(theta):
     """
     interval = 180
 
-    remaining_indices = list(np.argsort(theta))   # indices into theta
+    remaining_indices = list(np.argsort(theta))  # indices into theta
     # yield an arbitrary angle to start things off
     angle = theta[remaining_indices[0]]
     yield remaining_indices.pop(0)
     # determine subsequent angles using the golden ratio method
-    angle_increment = interval / golden_ratio ** 2
+    angle_increment = interval / golden_ratio**2
     while remaining_indices:
         remaining_angles = theta[remaining_indices]
         angle = (angle + angle_increment) % interval
@@ -363,8 +382,15 @@ def order_angles_golden_ratio(theta):
             yield remaining_indices.pop(index_above)
 
 
-def iradon_sart(radon_image, theta=None, image=None, projection_shifts=None,
-                clip=None, relaxation=0.15, dtype=None):
+def iradon_sart(
+    radon_image,
+    theta=None,
+    image=None,
+    projection_shifts=None,
+    clip=None,
+    relaxation=0.15,
+    dtype=None,
+):
     """Inverse radon transform.
 
     Reconstruct an image from the radon transform, using a single iteration of
@@ -372,20 +398,18 @@ def iradon_sart(radon_image, theta=None, image=None, projection_shifts=None,
 
     Parameters
     ----------
-    radon_image : 2D array
+    radon_image : ndarray, shape (M, N)
         Image containing radon transform (sinogram). Each column of
         the image corresponds to a projection along a different angle. The
         tomography rotation axis should lie at the pixel index
         ``radon_image.shape[0] // 2`` along the 0th dimension of
         ``radon_image``.
-    theta : 1D array, optional
+    theta : array, shape (N,), optional
         Reconstruction angles (in degrees). Default: m angles evenly spaced
         between 0 and 180 (if the shape of `radon_image` is (N, M)).
-    image : 2D array, optional
-        Image containing an initial reconstruction estimate. Shape of this
-        array should be ``(radon_image.shape[0], radon_image.shape[0])``. The
-        default is an array of zeros.
-    projection_shifts : 1D array, optional
+    image : ndarray, shape (M, M), optional
+        Image containing an initial reconstruction estimate. Default is an array of zeros.
+    projection_shifts : array, shape (N,), optional
         Shift the projections contained in ``radon_image`` (the sinogram) by
         this many pixels before reconstructing the image. The i'th value
         defines the shift of the i'th column of ``radon_image``.
@@ -447,13 +471,16 @@ def iradon_sart(radon_image, theta=None, image=None, projection_shifts=None,
         if radon_image.dtype.char in 'fd':
             dtype = radon_image.dtype
         else:
-            warn("Only floating point data type are valid for SART inverse "
-                 "radon transform. Input data is cast to float. To disable "
-                 "this warning, please cast image_radon to float.")
+            warn(
+                "Only floating point data type are valid for SART inverse "
+                "radon transform. Input data is cast to float. To disable "
+                "this warning, please cast image_radon to float."
+            )
             dtype = np.dtype(float)
     elif np.dtype(dtype).char not in 'fd':
-        raise ValueError("Only floating point data type are valid for inverse "
-                         "radon transform.")
+        raise ValueError(
+            "Only floating point data type are valid for inverse " "radon transform."
+        )
 
     dtype = np.dtype(dtype)
     radon_image = radon_image.astype(dtype, copy=False)
@@ -461,33 +488,34 @@ def iradon_sart(radon_image, theta=None, image=None, projection_shifts=None,
     reconstructed_shape = (radon_image.shape[0], radon_image.shape[0])
 
     if theta is None:
-        theta = np.linspace(0, 180, radon_image.shape[1],
-                            endpoint=False, dtype=dtype)
+        theta = np.linspace(0, 180, radon_image.shape[1], endpoint=False, dtype=dtype)
     elif len(theta) != radon_image.shape[1]:
-        raise ValueError('Shape of theta (%s) does not match the '
-                         'number of projections (%d)'
-                         % (len(theta), radon_image.shape[1]))
+        raise ValueError(
+            f'Shape of theta ({len(theta)}) does not match the '
+            f'number of projections ({radon_image.shape[1]})'
+        )
     else:
         theta = np.asarray(theta, dtype=dtype)
 
     if image is None:
         image = np.zeros(reconstructed_shape, dtype=dtype)
     elif image.shape != reconstructed_shape:
-        raise ValueError('Shape of image (%s) does not match first dimension '
-                         'of radon_image (%s)'
-                         % (image.shape, reconstructed_shape))
+        raise ValueError(
+            f'Shape of image ({image.shape}) does not match first dimension '
+            f'of radon_image ({reconstructed_shape})'
+        )
     elif image.dtype != dtype:
-        warn(f'image dtype does not match output dtype: '
-             f'image is cast to {dtype}')
+        warn(f'image dtype does not match output dtype: ' f'image is cast to {dtype}')
 
     image = np.asarray(image, dtype=dtype)
 
     if projection_shifts is None:
         projection_shifts = np.zeros((radon_image.shape[1],), dtype=dtype)
     elif len(projection_shifts) != radon_image.shape[1]:
-        raise ValueError('Shape of projection_shifts (%s) does not match the '
-                         'number of projections (%d)'
-                         % (len(projection_shifts), radon_image.shape[1]))
+        raise ValueError(
+            f'Shape of projection_shifts ({len(projection_shifts)}) does not match the '
+            f'number of projections ({radon_image.shape[1]})'
+        )
     else:
         projection_shifts = np.asarray(projection_shifts, dtype=dtype)
     if clip is not None:
@@ -496,9 +524,12 @@ def iradon_sart(radon_image, theta=None, image=None, projection_shifts=None,
         clip = np.asarray(clip, dtype=dtype)
 
     for angle_index in order_angles_golden_ratio(theta):
-        image_update = sart_projection_update(image, theta[angle_index],
-                                              radon_image[:, angle_index],
-                                              projection_shifts[angle_index])
+        image_update = sart_projection_update(
+            image,
+            theta[angle_index],
+            radon_image[:, angle_index],
+            projection_shifts[angle_index],
+        )
         image += relaxation * image_update
         if clip is not None:
             image = np.clip(image, clip[0], clip[1])
