@@ -1,10 +1,15 @@
+import copy
+
 import numpy as np
 
 from .._shared.filters import gaussian
 from .._shared.utils import check_nD
 from .brief_cy import _brief_loop
-from .util import (DescriptorExtractor, _mask_border_keypoints,
-                   _prepare_grayscale_input_2D)
+from .util import (
+    DescriptorExtractor,
+    _mask_border_keypoints,
+    _prepare_grayscale_input_2D,
+)
 
 
 class BRIEF(DescriptorExtractor):
@@ -32,19 +37,21 @@ class BRIEF(DescriptorExtractor):
     mode : {'normal', 'uniform'}, optional
         Probability distribution for sampling location of decision pixel-pairs
         around keypoints.
-    sample_seed : {None, int, `numpy.random.Generator`}, optional
-        If `sample_seed` is None the `numpy.random.Generator` singleton is
-        used.
-        If `sample_seed` is an int, a new ``Generator`` instance is used,
-        seeded with `sample_seed`.
-        If `sample_seed` is already a ``Generator`` instance then that instance
-        is used.
+    rng : {`numpy.random.Generator`, int}, optional
+        Pseudo-random number generator (RNG).
+        By default, a PCG64 generator is used (see :func:`numpy.random.default_rng`).
+        If `rng` is an int, it is used to seed the generator.
 
-        Seed for the random sampling of the decision pixel-pairs. From a square
-        window with length `patch_size`, pixel pairs are sampled using the
-        `mode` parameter to build the descriptors using intensity comparison.
-        The value of `sample_seed` must be the same for the images to be
-        matched while building the descriptors.
+        The PRNG is used for the random sampling of the decision
+        pixel-pairs. From a square window with length `patch_size`,
+        pixel pairs are sampled using the `mode` parameter to build
+        the descriptors using intensity comparison.
+
+        For matching across images, the same `rng` should be used to construct
+        descriptors. To facilitate this:
+
+        (a) `rng` defaults to 1
+        (b) Subsequent calls of the ``extract`` method will use the same rng/seed.
     sigma : float, optional
         Standard deviation of the Gaussian low-pass filter applied to the image
         to alleviate noise sensitivity, which is strongly recommended to obtain
@@ -58,7 +65,7 @@ class BRIEF(DescriptorExtractor):
         index ``(i, j)`` either being ``True`` or ``False`` representing
         the outcome of the intensity comparison for i-th keypoint on j-th
         decision pixel-pair. It is ``Q == np.sum(mask)``.
-    mask : (N, ) array of dtype bool
+    mask : (N,) array of dtype bool
         Mask indicating whether a keypoint has been filtered out
         (``False``) or is described in the `descriptors` array (``True``).
 
@@ -116,9 +123,9 @@ class BRIEF(DescriptorExtractor):
 
     """
 
-    def __init__(self, descriptor_size=256, patch_size=49,
-                 mode='normal', sigma=1, sample_seed=1):
-
+    def __init__(
+        self, descriptor_size=256, patch_size=49, mode='normal', sigma=1, rng=1
+    ):
         mode = mode.lower()
         if mode not in ('normal', 'uniform'):
             raise ValueError("`mode` must be 'normal' or 'uniform'.")
@@ -128,10 +135,18 @@ class BRIEF(DescriptorExtractor):
         self.mode = mode
         self.sigma = sigma
 
-        if sample_seed is None:
-            self.sample_seed = np.random.SeedSequence().entropy
+        if isinstance(rng, np.random.Generator):
+            # Spawn an independent RNG from parent RNG provided by the user.
+            # This is necessary so that we can safely deepcopy the RNG.
+            # See https://github.com/scikit-learn/scikit-learn/issues/16988#issuecomment-1518037853
+            bg = rng._bit_generator
+            ss = bg._seed_seq
+            (child_ss,) = ss.spawn(1)
+            self.rng = np.random.Generator(type(bg)(child_ss))
+        elif rng is None:
+            self.rng = np.random.default_rng(np.random.SeedSequence())
         else:
-            self.sample_seed = sample_seed
+            self.rng = np.random.default_rng(rng)
 
         self.descriptors = None
         self.mask = None
@@ -149,31 +164,30 @@ class BRIEF(DescriptorExtractor):
         """
         check_nD(image, 2)
 
-        random = np.random.default_rng(self.sample_seed)
+        # Copy RNG so we can repeatedly call extract with the same random values
+        rng = copy.deepcopy(self.rng)
 
         image = _prepare_grayscale_input_2D(image)
 
         # Gaussian low-pass filtering to alleviate noise sensitivity
-        image = np.ascontiguousarray(
-            gaussian(image, self.sigma, mode='reflect')
-        )
+        image = np.ascontiguousarray(gaussian(image, sigma=self.sigma, mode='reflect'))
 
         # Sampling pairs of decision pixels in patch_size x patch_size window
         desc_size = self.descriptor_size
         patch_size = self.patch_size
         if self.mode == 'normal':
-            samples = (patch_size / 5.0) * random.standard_normal(desc_size
-                                                                  * 8)
+            samples = (patch_size / 5.0) * rng.standard_normal(desc_size * 8)
             samples = np.array(samples, dtype=np.int32)
-            samples = samples[(samples < (patch_size // 2))
-                              & (samples > - (patch_size - 2) // 2)]
+            samples = samples[
+                (samples < (patch_size // 2)) & (samples > -(patch_size - 2) // 2)
+            ]
 
-            pos1 = samples[:desc_size * 2].reshape(desc_size, 2)
-            pos2 = samples[desc_size * 2:desc_size * 4].reshape(desc_size, 2)
+            pos1 = samples[: desc_size * 2].reshape(desc_size, 2)
+            pos2 = samples[desc_size * 2 : desc_size * 4].reshape(desc_size, 2)
         elif self.mode == 'uniform':
-            samples = random.integers(-(patch_size - 2) // 2,
-                                      (patch_size // 2) + 1,
-                                      (desc_size * 2, 2))
+            samples = rng.integers(
+                -(patch_size - 2) // 2, (patch_size // 2) + 1, (desc_size * 2, 2)
+            )
             samples = np.array(samples, dtype=np.int32)
             pos1, pos2 = np.split(samples, 2)
 
@@ -182,14 +196,14 @@ class BRIEF(DescriptorExtractor):
 
         # Removing keypoints that are within (patch_size / 2) distance from the
         # image border
-        self.mask = _mask_border_keypoints(image.shape, keypoints,
-                                           patch_size // 2)
+        self.mask = _mask_border_keypoints(image.shape, keypoints, patch_size // 2)
 
-        keypoints = np.array(keypoints[self.mask, :], dtype=np.int64,
-                             order='C', copy=False)
+        keypoints = np.array(
+            keypoints[self.mask, :], dtype=np.int64, order='C', copy=False
+        )
 
-        self.descriptors = np.zeros((keypoints.shape[0], desc_size),
-                                    dtype=bool, order='C')
+        self.descriptors = np.zeros(
+            (keypoints.shape[0], desc_size), dtype=bool, order='C'
+        )
 
-        _brief_loop(image, self.descriptors.view(np.uint8), keypoints,
-                    pos1, pos2)
+        _brief_loop(image, self.descriptors.view(np.uint8), keypoints, pos1, pos2)
